package com.glxp.udidl.admin.controller.tyapi;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.glxp.udidl.admin.annotation.AuthRuleAnnotation;
import com.glxp.udidl.admin.dto.udplat.UdplatManufactureModel;
import com.glxp.udidl.admin.entity.tyapi.TyCompanyDetailEntity;
import com.glxp.udidl.admin.entity.tyapi.TyCompanySearchEntity;
import com.glxp.udidl.admin.entity.tyapi.TySupplierEntity;
import com.glxp.udidl.admin.req.tyapi.TyBaseInfoRequest;
import com.glxp.udidl.admin.res.BaseResponse;
import com.glxp.udidl.admin.res.tyapi.TyBatchDlResponse;
import com.glxp.udidl.admin.res.tyapi.TyContactResponse;
import com.glxp.udidl.admin.service.tyapi.TyCompanyDetailService;
import com.glxp.udidl.admin.service.tyapi.TyCompanySearchService;
import com.glxp.udidl.admin.service.tyapi.TyContactInfoService;
import com.glxp.udidl.admin.service.tyapi.TySupplierService;
import com.glxp.udidl.admin.util.ResultVOUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@Api(tags = "天眼查API接口")
@RestController
public class TySearchController {

    @Resource
    TyCompanySearchService tyCompanySearchService;
    @Resource
    TySupplierService tySupplierService;
    @Resource
    TyCompanyDetailService tyCompanyDetailService;
    @Resource
    TyContactInfoService tyContactInfoService;

    @ApiOperation(value = "天眼查企业信息查询", response = TyCompanySearchEntity.class)
    @GetMapping("udidl/ty/company/findBycCeditCode")
    public BaseResponse findBycCeditCode(String creditCode) {

        if (StrUtil.isEmpty(creditCode)) {
            return ResultVOUtils.error(500, "统一社会信用代码不能为空！");
        }
        List<TyCompanySearchEntity> tyCompanySearchEntityList = tyCompanySearchService.list(new QueryWrapper<TyCompanySearchEntity>().eq("creditCode", creditCode));
        if (CollUtil.isEmpty(tyCompanySearchEntityList)) {
            return ResultVOUtils.error(500, "查无企业信息");
        } else {
            return ResultVOUtils.success(tyCompanySearchEntityList.get(0));
        }
    }

    @ApiOperation(value = "天眼查批量下载供应商列表接口")
    @PostMapping("/udidl/ty/company/batch/supplier")
    public BaseResponse imports(@RequestBody String hospitals) {
        if (StrUtil.isEmpty(hospitals)) {
            return ResultVOUtils.error(500, "医院名称列表不能为空");
        }
        String[] hospAarray = hospitals.split(",");
        TyBatchDlResponse tyBatchDlResponse = new TyBatchDlResponse();
        List<TyCompanyDetailEntity> mTyCompanyDetailEntities = new ArrayList<>();
        List<TyContactResponse> mTyContactResponses = new ArrayList<>();
        List<TySupplierEntity> mTySupplierEntities = new ArrayList<>();
        for (int i = 0; i < hospAarray.length; i++) {
            tySupplierService.download(hospAarray[i]);
            List<TySupplierEntity> tySupplierEntities = tySupplierService.list(new QueryWrapper<TySupplierEntity>().eq("hospName", hospAarray[i]));
            if (CollUtil.isNotEmpty(tySupplierEntities)) {
                mTySupplierEntities.addAll(tySupplierEntities);
                for (TySupplierEntity tySupplierEntity : tySupplierEntities) {
                    TyCompanyDetailEntity tyCompanyDetailEntity = tyCompanyDetailService.download(tySupplierEntity.getSupplier_name());
                    if (tyCompanyDetailEntity != null)
                        mTyCompanyDetailEntities.add(tyCompanyDetailEntity);
                    List<TyContactResponse> tyContactResponses = tyContactInfoService.download(tySupplierEntity.getSupplier_name());
                    if (CollUtil.isNotEmpty(tyContactResponses)) {
                        mTyContactResponses.addAll(tyContactResponses);
                    }
                }
            }
        }
        tyBatchDlResponse.setTyContactResponses(mTyContactResponses);
        tyBatchDlResponse.setTyCompanyDetailEntities(mTyCompanyDetailEntities);
        tyBatchDlResponse.setTySupplierEntities(mTySupplierEntities);
        return ResultVOUtils.success(tyBatchDlResponse);
    }

    @ApiOperation(value = "天眼查批量下载企业详细信息接口")
    @GetMapping("/udidl/ty/company/getBaseInfo")
    public BaseResponse getCompanyInfo(TyBaseInfoRequest tyBaseInfoRequest) {
        if (StrUtil.isEmpty(tyBaseInfoRequest.getName()) && StrUtil.isEmpty(tyBaseInfoRequest.getCreditCode())) {
            return ResultVOUtils.error(500, "请输入企业名称或统一社会信用代码");
        }
        String keyWord = "";
        if (StrUtil.isNotEmpty(tyBaseInfoRequest.getCreditCode())) {
            keyWord = tyBaseInfoRequest.getCreditCode();
        } else
            keyWord = tyBaseInfoRequest.getName();
        TyCompanyDetailEntity tyCompanyDetailEntity = tyCompanyDetailService.download(keyWord);
        return ResultVOUtils.success(tyCompanyDetailEntity);

    }

}
